- Vue d'ensemble (Overview)
- Prérequis
- Pré-installation
- Préparation de l'installation
- Téléchargement des packages d'installation
- Configuration du registre conforme à OCI
- Octroi d'autorisations d'installation
- Installation et configuration du service Mesh
- Installer et configurer l'outil GitOps
- Installation de l'opérateur de clés secrètes externes dans Kubernetes
- Application de diverses configurations
- Exécution de uipathctl
- Installation
- Post-installation
- Migration et mise à niveau
- Surveillance et alerte
- Administration du cluster
- Configuration spécifique au produit
- Configuration avancée d'Orchestrator
- Configuration des paramètres d'Orchestrator
- Configuration des paramètres d'application
- Configuration de la taille maximale de la requête
- Remplacement de la configuration du stockage au niveau du cluster
- Configuration de NLog
- Enregistrement des journaux du robot dans Elasticsearch
- Configuration des magasins d'informations d'identification
- Configuration de la clé de chiffrement par locataire
- Nettoyer la base de données Orchestrator
- Ignorer l’installation de la bibliothèque hôte
- Rotation des informations d’identification de stockage d’objets blob
- Désactivation de l'utilisation d'URL pré-signées lors du téléchargement de données vers le stockage Amazon S3
- Configuration de la sécurité de l'application de processus
- Configurer une authentification Kerberos avec l’authentification MSSQL de base pour Process Mining
- AI Trust Layer
- Résolution des problèmes
- Échec de l’enregistrement d’AI Center après la mise à niveau vers la version 2023.10 ou une version ultérieure
- Volumes Insights créés dans deux zones différentes après la migration
- La mise à niveau échoue en raison du remplacement des tailles de PVC Insights
- Les composants de sauvegarde Velero restent après la mise à niveau sur AKS depuis Automation Suite 2024.10.x
- La configuration de sauvegarde ne fonctionne pas en raison d’un échec de connexion à Azure Government
- Pods dans l'espace de noms uipath bloqués lors de l'activation des rejets de nœuds personnalisés
- Impossible de lancer Automation Hub et Apps avec la configuration proxy
- La sauvegarde de Velero échoue avec l'erreur FailedValidation
- Résolution des problèmes de clés secrètes externes
- Résolution des problèmes de Temporel en tant que service
- Les pods AI Center et Document Understanding ne démarrent pas avec la vérification du certificat TLS activée
- Erreurs de validation du certificat TLS
- Fluentd n’exporte pas les journaux dans les environnements IPv6
- Studio Desktop ne peut pas charger les connecteurs et activités Integration Service
- Atténuation manuelle de la politique réseau ArgoCD
- Configurer les requêtes et les limites de ressources pour les charges de travail créées par uipathctl
Remplacement de la configuration du stockage au niveau du cluster
Remplacez la classe de stockage et la configuration de stockage au niveau du cluster dans Automation Suite sur EKS/AKS.
Orchestrator prend en charge les configurations de stockage suivantes :
- Configuration du stockage au niveau du cluster
- Configuration du stockage au niveau d'Orchestrator
Nous vous recommandons d'utiliser la configuration au niveau du cluster associée au stockage externe. Cela permet à Orchestrator de détecter et d'utiliser automatiquement les paramètres, éliminant ainsi le besoin d'une configuration supplémentaire.
Configuration des compartiments de stockage Azure/Amazon S3
To configure the Orchestrator-level storage provider, update the Orchestrator parameters by taking the following steps. For details, refer to Configuring Orchestrator parameters.
-
Dans le fichier de configuration, sous
orchestrator, ajoutez la sectionlegacy_storage_providerqui contient le type de stockage et la chaîne de connexion, comme illustré dans l'exemple suivant :"orchestrator": { "enabled": true, "legacy_object_storage": { "type": "Azure", "connection_string": "DefaultEndpointsProtocol=https;AccountName=usr;AccountKey=...;EndpointSuffix=core.windows.net" } }"orchestrator": { "enabled": true, "legacy_object_storage": { "type": "Azure", "connection_string": "DefaultEndpointsProtocol=https;AccountName=usr;AccountKey=...;EndpointSuffix=core.windows.net" } } -
Définissez le fournisseur souhaité à l'aide du paramètre
type. Les valeurs possibles sont :Azure,AWSetMinio. Quelques considérations :- Les valeurs du paramètre
storage.typesont sensibles à la casse. - La configuration de stockage
FileSystemn'est pas prise en charge.
- Les valeurs du paramètre
-
Ajoutez la chaîne de connexion pour le fournisseur de stockage à l'aide du paramètre
connection_string. Pour plus de détails sur le format des chaînes de connexion, reportez-vous à la sectionStorage.Locationde fichier UiPath.Orchestrator.dll.config.
L’accès du navigateur Web Orchestrator aux compartiments de stockage Amazon et Azure peut être restreint en raison de la politique de même origine côté fournisseur. Pour accéder avec succès au contenu d’un tel compartiment, vous devez configurer le fournisseur concerné pour autoriser les requêtes d’origine croisée générées depuis Orchestrator. Pour obtenir des instructions, consultez la section Configuration CORS/CSP.
Téléchargement de fichiers vers un espace de stockage
Des fichiers peuvent être téléchargés sur le stockage à l'aide de l'outil de ligne de commande uipathctl . Pour ce faire, utilisez la commande suivante :
uipathctl config orchestrator upload [parameters]
uipathctl config orchestrator upload [parameters]
| Paramètre | Description |
|---|---|
--storage-directory <string> | Emplacement du répertoire de stockage sur le disque local. |
--nlog-extensions-directory <string> | Emplacement des extensions NLog sur le disque local. |
--securestore-plugins-directory <string> | Emplacement des plug-ins du magasin sécurisés sur le disque local. |
--is-external-storage | Indique si le stockage est externe ou non. |
--namespace <string> | L'espace de noms dans lequel Automation Suite est déployé. La valeur par défaut est uipath. |
-h, --help | Fournit une aide pour la commande de téléchargement. |
Si vous utilisez une configuration de stockage externe au niveau du cluster, vous devez l'indiquer en incluant le paramètre --is-external-storage lors de l'utilisation de la commande.
Considérations de chargement de stockage
Le répertoire spécifié à l'aide du paramètre --storage-directory doit contenir au moins un sous-répertoire. Tous les sous-répertoires sont copiés dans le stockage.
Les fichiers téléchargés vers le dossier racine à l'aide de --storage-directory sont ignorés.
Stockage interne
Les sous-répertoires sont copiés directement dans le compartiment en utilisant le nom du sous-répertoire comme chemin.
Stockage externe
- Si le sous-répertoire est nommé
orchestrator-host, son contenu est copié dans le chemin d'accèsOrchestrator-Host. - Si le sous-répertoire est nommé
orchestrator-<name>, son contenu est copié dans le chemin d'accèsO<name>. - Dans tous les autres cas, le contenu du sous-répertoire est copié dans le chemin d'accès
<name>.
Exemples d'utilisation
-
Téléchargement de fichiers vers un espace de stockage :
uipathctl config orchestrator upload --storage-directory /path/to/storage/directoryuipathctl config orchestrator upload --storage-directory /path/to/storage/directory -
Téléchargement des extensions NLog vers le stockage :
uipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directoryuipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directory -
Téléchargement des plug-ins de magasin sécurisés vers le stockage :
uipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directoryuipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directory -
Téléchargement de fichiers vers un stockage externe :
uipathctl config orchestrator upload --is-external-storage --storage-directory /path/to/storage/directoryuipathctl config orchestrator upload --is-external-storage --storage-directory /path/to/storage/directory -
Téléchargement des extensions NLog vers un stockage externe :
uipathctl config orchestrator upload --is-external-storage --nlog-extensions-directory /path/to/nlog/extensions/directoryuipathctl config orchestrator upload --is-external-storage --nlog-extensions-directory /path/to/nlog/extensions/directory -
Téléchargement de plug-ins de magasin sécurisés vers un stockage externe :
uipathctl config orchestrator upload --is-external-storage --securestore-plugins-directory /path/to/securestore/plugins/directoryuipathctl config orchestrator upload --is-external-storage --securestore-plugins-directory /path/to/securestore/plugins/directory